@@ -1,10 +1,11 @@
 import os
+
 from cloudmesh.burn.image import Image
 
 
 class Iso:
     distribution = {
-        "latest": "https://downloads.raspberrypi.org/rpd_x86/images/rpd_x86-2021-01-12/2021-01-11-raspios-buster-i386.iso"
+        "latest": "https://downloads.raspberrypi.org/rpd_x86/images/rpd_x86-2021-01-12/2021-01-11-raspios-buster-i386.iso"  # noqa: E501
     }
 
     @staticmethod
