@@ -2,7 +2,7 @@ import inspect
 import os.path
 import time
 
-import PySimpleGUI as sg
+import PySimpleGUI as sg  # noqa
 import oyaml as yaml
 from cloudmesh.burn.usb import USB
 from cloudmesh.burn.util import os_is_linux
@@ -16,6 +16,8 @@ from cloudmesh.common.sudo import Sudo
 from cloudmesh.common.util import banner
 from cloudmesh.common.util import path_expand
 from cloudmesh.diagram.diagram import Diagram
+from cloudmesh.burn.wifi.ssid import get_ssid
+from cloudmesh.burn.command.burn import _build_default_inventory
 
 
 def _execute(command):
@@ -57,15 +59,17 @@ image_tags = {
 
 class Gui:
 
-    def __init__(self, hostname=None, ip=None, dryrun=False):
+    def __init__(self, hostname=None, ip=None, dryrun=False, no_diagram=False):
 
         self.dryrun = dryrun or False
         self.hostnames_str = hostname
         self.ips_str = ip
         self.hostnames = hostnames = hostname or "red,red[01-02]"
         self.ips = ips = ip or "10.0.0.[1-3]"
-        self.ssid = ""
+        self.ssid = get_ssid()
         self.imaged = ""
+        self.wifipassword = ""
+        self.no_diagram = no_diagram
 
         hostnames = Parameter.expand(hostnames)
         manager, workers = Host.get_hostnames(hostnames)
@@ -74,7 +78,7 @@ class Gui:
             n = 1
         else:
             n = len(workers) + 1
-        if ips is None:
+        if ip is None:
             ips = Parameter.expand(f"10.1.1.[1-{n}]")
         else:
             ips = Parameter.expand(ips)
@@ -97,13 +101,14 @@ class Gui:
 
         self.load_data()
 
-        self.create_diag(self.manager)
+        if not self.no_diagram:
+            self.create_diag(self.manager)
         self.create_layout()
         # sg.change_look_and_feel('SystemDefault')
         self.window = sg.Window('Cloudmesh Pi Burn', self.layout, resizable=True, size=window_size)
 
     def burn(self, kind, hostname):
-        '''
+        """
         if hostname == 'red':
             ip = self.ips[0]
             print("in red")
@@ -115,7 +120,7 @@ class Gui:
             ip = self.ips[ip_location]
             print("in red")
             print(ip)
-        '''
+        """
 
         return
 
@@ -172,13 +177,17 @@ class Gui:
             [sg.T('')]
         ]
 
-        net_layout = [
-            [sg.Image(data=image(net_file), key='net-image', background_color='white')]
+        if not self.no_diagram:
+            net_layout = [
+                [sg.Image(data=image(net_file), key='net-image', background_color='white')]
 
-        ]
-        rack_layout = [
-            [sg.Image(data=image(rack_file), key='rack-image', background_color='white')]
-        ]
+            ]
+            rack_layout = [
+                [sg.Image(data=image(rack_file), key='rack-image', background_color='white')]
+            ]
+        else:
+            net_layout = []
+            rack_layout = []
 
         size = log_size
         log_layout = [[sg.T('', key="log", size=size)]]
@@ -208,9 +217,16 @@ class Gui:
         count = 0
         for device in devices:
             default = count == 0
-            burn_layout.append(
-                [sg.Radio(device, group_id="DEVICE", default=default, key=f"device-{device}")]
-            )
+            if os_is_linux():
+                burn_layout.append(
+                    [sg.Radio(device, group_id="DEVICE",
+                              default=default,
+                              key=f"device-{device['name']}")]
+                )
+            else:
+                burn_layout.append(
+                    [sg.Radio(device, group_id="DEVICE", default=default, key=f"device-{device}")]
+                )
             count = count + 1
 
         #
@@ -248,7 +264,7 @@ class Gui:
         if self.key is not None:
             burn_layout.append([sg.Text("Key", size=security_width), sg.Input(key="key", default_text=self.key)])
 
-        burn_layout.append([sg.Text("SSID", size=security_width), sg.Input(key="ssid", default_text="")])
+        burn_layout.append([sg.Text("SSID", size=security_width), sg.Input(key="ssid", default_text=self.ssid)])
         burn_layout.append(
             [sg.Text("Wifi Password", size=security_width), sg.Input(key="wifi", default_text="", password_char='*')])
 
@@ -346,7 +362,7 @@ class Gui:
             text = self.window['log']
             text.update(text.get() + msg + end)
             self.window.Refresh()
-        except:
+        except:  # noqa
             print(msg)
 
     def set_diagram_value(self, name, entry, attribute, value):
@@ -379,7 +395,7 @@ class Gui:
         try:
             self.window.FindElement(f'button-{host}').Update(button_color=('white', color))
             self.window.Refresh()
-        except:
+        except:   # noqa
             pass
 
     def run(self):
@@ -400,6 +416,11 @@ class Gui:
             event, values = self.window.read()
 
             if event in ("Cancel", 'cancel', None):
+                if not self.no_diagram:
+                    rack_file = f"~/.cloudmesh/gui/{self.manager}-rack.png"
+                    net_file = f"~/.cloudmesh/gui/{self.manager}-net.png"
+                    os.remove(path_expand(rack_file))
+                    os.remove(path_expand(net_file))
                 break
 
             #
@@ -435,6 +456,7 @@ class Gui:
                 #
                 ips = []
                 hostnames = []
+                tags = []
                 for entry in values:
                     if str(entry).startswith("name"):
                         hostnames.append(values[entry])
@@ -442,6 +464,8 @@ class Gui:
                         ips.append(values[entry])
                     if str(entry).startswith("device-") and values[entry]:
                         device = "/dev/" + entry.replace("device-", "")
+                    if str(entry).startswith("tag") and values[entry]:
+                        tags.append(values[entry])
                 key = values['key']
                 self.hostnames_str = ','.join(hostnames)
                 self.ips_str = ','.join(ips)
@@ -449,6 +473,7 @@ class Gui:
                 # get the ssid
                 #
                 self.ssid = values['ssid']
+                self.wifipassword = values['wifi']
 
                 host = event.replace("button-", "")
                 self.set_button_color(host, 'grey')
@@ -472,21 +497,35 @@ class Gui:
 
                 # Call burn function for manager and workers
                 self.logger(f"Burning {kind} {host}")
-                tags = values[f'tags-{host}']
+                # tags = values[f'tags-{host}']
                 self.window[f'status-{host}'].update(' Burning ')
 
-                self.update_diagram_colors(self.manager, host, "blue")
-
+                if not self.no_diagram:
+                    self.update_diagram_colors(self.manager, host, "blue")
                 self.hostnames_str = ','.join(hostnames)
                 self.ips_str = ','.join(ips)
-                command = "cms burn cluster --device=/dev/disk2" \
-                          f" --hostname={self.hostnames_str}" \
-                          f" --ssid={self.ssid}" \
-                          f" --ip={self.ips_str}" \
-                          f" --burning={host}" \
-                          " -y" \
-                          f" {self.imaged_str}"
-                print(command)
+                # command = f"cms burn cluster --device={device}" \
+                #          f" --hostname={self.hostnames_str}" \
+                #          f" --ssid={self.ssid}" \
+                #          f" --wifipassword={self.wifipassword}" \
+                #          f" --ip={self.ips_str}" \
+                #          f" --burning={host}" \
+                #          " -y" \
+                #          f" {self.imaged_str}"
+
+                manager, workers = Host.get_hostnames(hostnames)
+                filename = path_expand(f"~/.cloudmesh/inventory-{manager}.yml")
+                _build_default_inventory(filename=filename, manager=manager,
+                                         workers=workers, ips=ips, images=tags)
+                if host == manager:
+                    command = f"cms burn raspberry {host}" \
+                              f" --device={device}" \
+                              f" --ssid={self.ssid}" \
+                              f" --wifipassword={self.wifipassword}"
+                else:
+                    command = f"cms burn raspberry {host}" \
+                              f" --device={device}"
+                    print(command)
 
                 try:
                     self.logger(f"Executing: {command}")
@@ -495,14 +534,15 @@ class Gui:
                     else:
                         os.system(command)
                     self.window[f'status-{host}'].update(' Completed ')
-
-                    self.update_diagram_colors(self.manager, host, "green")
+                    if not self.no_diagram:
+                        self.update_diagram_colors(self.manager, host, "green")
                     self.set_button_color(host, 'green')
 
                 except Exception as e:
                     print(e)
                     self.logger("Command failed")
-                    self.update_diagram_colors(self.manager, host, "orange")
+                    if not self.no_diagram:
+                        self.update_diagram_colors(self.manager, host, "orange")
                     self.set_button_color(host, 'red')
 
                 self.window.FindElement(f'button-{host}').Update(button_color=('white', 'green'))
